Crate kcr_gateway_networking_x_k8s_io

Crate kcr_gateway_networking_x_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the gateway.networking.x-k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

gateway.networking.x-k8s.io/v1alpha1

  • XBackendTrafficPolicy
  • XListenerSet

Modules

v1alpha1